@@ -148,7 +148,7 @@ enum
 #define DEFAULT_USE_SYSTEM_FONT       (TRUE)
 #define DEFAULT_USE_THEME_COLORS      (TRUE)
 #define DEFAULT_VISIBLE_NAME          (N_("Unnamed"))
-#define DEFAULT_WORD_CHARS            ("-A-Za-z0-9,./?%&#:_")
+#define DEFAULT_WORD_CHARS            ("-A-Za-z0-9,./?%&#:_=+@~")
 
 struct _TerminalProfilePrivate
 {
@@ -184,7 +184,7 @@ static const GdkColor terminal_palettes[TERMINAL_PALETTE_N_BUILTINS][TERMINAL_PA
 {
   /* Tango palette */
   {
-    { 0, 0x2e2e, 0x3434, 0x3636 },
+    { 0, 0x0000, 0x0000, 0x0000 },
     { 0, 0xcccc, 0x0000, 0x0000 },
     { 0, 0x4e4e, 0x9a9a, 0x0606 },
     { 0, 0xc4c4, 0xa0a0, 0x0000 },
@@ -272,8 +272,6 @@ enum
   LAST_SIGNAL
 };
 
-static void terminal_profile_init        (TerminalProfile      *profile);
-static void terminal_profile_class_init  (TerminalProfileClass *klass);
 static void terminal_profile_finalize    (GObject              *object);
 static void terminal_profile_set_property (GObject *object,
                                            guint prop_id,
@@ -335,7 +333,7 @@ get_prop_value_from_prop_name (TerminalProfile *profile,
 }
 
 static void
-set_value_from_palette (GValue *value,
+set_value_from_palette (GValue *ret_value,
                         const GdkColor *colors,
                         guint n_colors)
 {
@@ -364,7 +362,7 @@ set_value_from_palette (GValue *value,
       g_value_set_boxed (value, &DEFAULT_PALETTE[i]);
     }
 
-  g_value_take_boxed (value, array);
+  g_value_take_boxed (ret_value, array);
 }
 
 static int
@@ -844,7 +842,7 @@ cleanup:
   g_free (key);
 }
 
-static gboolean
+static void
 terminal_profile_save (TerminalProfile *profile)
 {
   TerminalProfilePrivate *priv = profile->priv;
@@ -879,8 +877,6 @@ terminal_profile_save (TerminalProfile *profile)
     }
 
   gconf_change_set_unref (changeset);
-
-  return error == NULL;
 }
 
 static gboolean
@@ -925,12 +921,6 @@ terminal_profile_init (TerminalProfile *profile)
 
   priv->locked = g_new0 (gboolean, LAST_PROP);
 
-  /* Lock all props by default. If GConf is working and allows writing
-   * to the resp. keys, we'll unlock in the notification handler.
-   */
-  for (i = 0; i < LAST_PROP; ++i)
-    priv->locked[i] = TRUE;
-
   priv->properties = g_value_array_new (LAST_PROP);
   for (i = 0; i < LAST_PROP; ++i)
     g_value_array_append (priv->properties, NULL);
@@ -1213,8 +1203,8 @@ terminal_profile_class_init (TerminalProfileClass *klass)
 \
   if (propGConf)\
     {\
-      g_param_spec_set_qdata (pspec, gconf_key_quark, propGConf);\
-      g_hash_table_insert (klass->gconf_keys, propGConf, pspec);\
+      g_param_spec_set_qdata (pspec, gconf_key_quark, (gpointer) propGConf);\
+      g_hash_table_insert (klass->gconf_keys, (gpointer) propGConf, pspec);\
     }\
 }
 
